@@ -7,7 +7,7 @@ use Carp;
 use Data::Dumper;
 use Log::Log4perl qw(get_logger);
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 sub new {
 	my ( $class, $fw ) = @_;
@@ -120,7 +120,7 @@ sub expand_all {
 			$self->expand( $clone, $expanded );
 		};
 		if ($@) {
-			confess "$@ \n expand failed for ", Dumper($ce), "\n";
+			confess "$@ \n expand failed for ", $ce->dump(), "\n";
 		}
 	}
 
@@ -283,7 +283,7 @@ __END__
 
 =head1 NAME
 
-Farly::Rules - Convert a firewall rule configuration into a raw rule set
+Farly::Rules - - Deprecated - is now Farly::Rule::Expander
 
 =head1 DESCRIPTION
 
